yakumo.keystone.v2.role

Package yakumo :: Package keystone :: Package v2 :: Module role |
[hide private]
[frames] | no frames]

# Source Code for Module yakumo.keystone.v2.role

     1  # Copyright 2014-2017 by Akira Yoshiyama <akirayoshiyama@gmail.com>.
     2  # All Rights Reserved.
     3  #
     4  #    Licensed under the Apache License, Version 2.0 (the "License"); you may
     5  #    not use this file except in compliance with the License. You may obtain
     6  #    a copy of the License at
     7  #
     8  #         http://www.apache.org/licenses/LICENSE-2.0
     9  #
    10  #    Unless required by applicable law or agreed to in writing, software
    11  #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
    12  #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
    13  #    License for the specific language governing permissions and limitations
    14  #    under the License.
    15
    16  """
    17  Resource class and its manager for roles in Identity V2 API
    18  """
    19
    20  from yakumo import base
    21  from yakumo.constant import UNDEF
    22  from yakumo import mapper
    23
    24
    25  ATTRIBUTE_MAPPING = [
    26      ('id', 'id', mapper.Noop),
    27      ('name', 'name', mapper.Noop),
    28      ('description', 'description', mapper.Noop),
    29  ]
    30
    31
    32 -class Resource(base.Resource):
    33      """resource class for roles on Identity V2 API"""
    34
    35
    36 -class Manager(base.Manager):
    37      """manager class for roles on Identity V2 API"""
    38
    39      resource_class = Resource
    40      service_type = 'identity'
    41      _attr_mapping = ATTRIBUTE_MAPPING
    42      _hidden_methods = ["update"]
    43      _json_resource_key = 'role'
    44      _json_resources_key = 'roles'
    45      _url_resource_path = '/OS-KSADM/roles'
    46
    47 -    def create(self, name=UNDEF, description=UNDEF):
    48          """
    49          Register a role
    50
    51          @keyword name: Role name
    52          @type name: str
    53          @keyword description: Description
    54          @type description: str
    55          @return: Created role
    56          @rtype: yakumo.keystone.v2.role.Resource
    57          """
    58          return super(Manager, self).create(name=name, description=description)
    59